# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Principal(object):
    """
    Principal model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Principal object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param subject_id:
            The value to assign to the subject_id property of this Principal.
        :type subject_id: str

        :param tenant_id:
            The value to assign to the tenant_id property of this Principal.
        :type tenant_id: str

        :param claims:
            The value to assign to the claims property of this Principal.
        :type claims: list[oci.identity_data_plane.models.Claim]

        """
        self.swagger_types = {
            'subject_id': 'str',
            'tenant_id': 'str',
            'claims': 'list[Claim]'
        }

        self.attribute_map = {
            'subject_id': 'subjectId',
            'tenant_id': 'tenantId',
            'claims': 'claims'
        }

        self._subject_id = None
        self._tenant_id = None
        self._claims = None

    @property
    def subject_id(self):
        """
        **[Required]** Gets the subject_id of this Principal.
        The user's OCID.


        :return: The subject_id of this Principal.
        :rtype: str
        """
        return self._subject_id

    @subject_id.setter
    def subject_id(self, subject_id):
        """
        Sets the subject_id of this Principal.
        The user's OCID.


        :param subject_id: The subject_id of this Principal.
        :type: str
        """
        self._subject_id = subject_id

    @property
    def tenant_id(self):
        """
        **[Required]** Gets the tenant_id of this Principal.
        The tenancy OCID.


        :return: The tenant_id of this Principal.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this Principal.
        The tenancy OCID.


        :param tenant_id: The tenant_id of this Principal.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def claims(self):
        """
        **[Required]** Gets the claims of this Principal.
        The set of claims for this principal.


        :return: The claims of this Principal.
        :rtype: list[oci.identity_data_plane.models.Claim]
        """
        return self._claims

    @claims.setter
    def claims(self, claims):
        """
        Sets the claims of this Principal.
        The set of claims for this principal.


        :param claims: The claims of this Principal.
        :type: list[oci.identity_data_plane.models.Claim]
        """
        self._claims = claims

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DowngradeHcxDetails(object):
    """
    The HCX on-premise license keys to be reserved when downgrading from HCX Enterprise to HCX Advanced.
    Downgrading from HCX Enterprise to HCX Advanced reduces the number of provided license keys from 10 to 3.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DowngradeHcxDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param reserving_hcx_on_premise_license_keys:
            The value to assign to the reserving_hcx_on_premise_license_keys property of this DowngradeHcxDetails.
        :type reserving_hcx_on_premise_license_keys: list[str]

        """
        self.swagger_types = {
            'reserving_hcx_on_premise_license_keys': 'list[str]'
        }

        self.attribute_map = {
            'reserving_hcx_on_premise_license_keys': 'reservingHcxOnPremiseLicenseKeys'
        }

        self._reserving_hcx_on_premise_license_keys = None

    @property
    def reserving_hcx_on_premise_license_keys(self):
        """
        **[Required]** Gets the reserving_hcx_on_premise_license_keys of this DowngradeHcxDetails.
        The HCX on-premise license keys to be reserved when downgrading from HCX Enterprise to HCX Advanced.


        :return: The reserving_hcx_on_premise_license_keys of this DowngradeHcxDetails.
        :rtype: list[str]
        """
        return self._reserving_hcx_on_premise_license_keys

    @reserving_hcx_on_premise_license_keys.setter
    def reserving_hcx_on_premise_license_keys(self, reserving_hcx_on_premise_license_keys):
        """
        Sets the reserving_hcx_on_premise_license_keys of this DowngradeHcxDetails.
        The HCX on-premise license keys to be reserved when downgrading from HCX Enterprise to HCX Advanced.


        :param reserving_hcx_on_premise_license_keys: The reserving_hcx_on_premise_license_keys of this DowngradeHcxDetails.
        :type: list[str]
        """
        self._reserving_hcx_on_premise_license_keys = reserving_hcx_on_premise_license_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AllowedPhaseTwoParameters(object):
    """
    Phase Two Parameters
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AllowedPhaseTwoParameters object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param encryption_algorithms:
            The value to assign to the encryption_algorithms property of this AllowedPhaseTwoParameters.
        :type encryption_algorithms: list[str]

        :param authentication_algorithms:
            The value to assign to the authentication_algorithms property of this AllowedPhaseTwoParameters.
        :type authentication_algorithms: list[str]

        :param pfs_dh_groups:
            The value to assign to the pfs_dh_groups property of this AllowedPhaseTwoParameters.
        :type pfs_dh_groups: list[str]

        """
        self.swagger_types = {
            'encryption_algorithms': 'list[str]',
            'authentication_algorithms': 'list[str]',
            'pfs_dh_groups': 'list[str]'
        }

        self.attribute_map = {
            'encryption_algorithms': 'encryptionAlgorithms',
            'authentication_algorithms': 'authenticationAlgorithms',
            'pfs_dh_groups': 'pfsDhGroups'
        }

        self._encryption_algorithms = None
        self._authentication_algorithms = None
        self._pfs_dh_groups = None

    @property
    def encryption_algorithms(self):
        """
        Gets the encryption_algorithms of this AllowedPhaseTwoParameters.
        Phase Two Encryption Algorithms


        :return: The encryption_algorithms of this AllowedPhaseTwoParameters.
        :rtype: list[str]
        """
        return self._encryption_algorithms

    @encryption_algorithms.setter
    def encryption_algorithms(self, encryption_algorithms):
        """
        Sets the encryption_algorithms of this AllowedPhaseTwoParameters.
        Phase Two Encryption Algorithms


        :param encryption_algorithms: The encryption_algorithms of this AllowedPhaseTwoParameters.
        :type: list[str]
        """
        self._encryption_algorithms = encryption_algorithms

    @property
    def authentication_algorithms(self):
        """
        Gets the authentication_algorithms of this AllowedPhaseTwoParameters.
        Phase Two Authentication Algorithms


        :return: The authentication_algorithms of this AllowedPhaseTwoParameters.
        :rtype: list[str]
        """
        return self._authentication_algorithms

    @authentication_algorithms.setter
    def authentication_algorithms(self, authentication_algorithms):
        """
        Sets the authentication_algorithms of this AllowedPhaseTwoParameters.
        Phase Two Authentication Algorithms


        :param authentication_algorithms: The authentication_algorithms of this AllowedPhaseTwoParameters.
        :type: list[str]
        """
        self._authentication_algorithms = authentication_algorithms

    @property
    def pfs_dh_groups(self):
        """
        Gets the pfs_dh_groups of this AllowedPhaseTwoParameters.
        PFS DH Groups


        :return: The pfs_dh_groups of this AllowedPhaseTwoParameters.
        :rtype: list[str]
        """
        return self._pfs_dh_groups

    @pfs_dh_groups.setter
    def pfs_dh_groups(self, pfs_dh_groups):
        """
        Sets the pfs_dh_groups of this AllowedPhaseTwoParameters.
        PFS DH Groups


        :param pfs_dh_groups: The pfs_dh_groups of this AllowedPhaseTwoParameters.
        :type: list[str]
        """
        self._pfs_dh_groups = pfs_dh_groups

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrSnapshotSummary(object):
    """
    The AWR snapshot summary of one snapshot.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrSnapshotSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param awr_source_database_id:
            The value to assign to the awr_source_database_id property of this AwrSnapshotSummary.
        :type awr_source_database_id: str

        :param instance_number:
            The value to assign to the instance_number property of this AwrSnapshotSummary.
        :type instance_number: int

        :param time_db_startup:
            The value to assign to the time_db_startup property of this AwrSnapshotSummary.
        :type time_db_startup: datetime

        :param time_snapshot_begin:
            The value to assign to the time_snapshot_begin property of this AwrSnapshotSummary.
        :type time_snapshot_begin: datetime

        :param time_snapshot_end:
            The value to assign to the time_snapshot_end property of this AwrSnapshotSummary.
        :type time_snapshot_end: datetime

        :param snapshot_identifier:
            The value to assign to the snapshot_identifier property of this AwrSnapshotSummary.
        :type snapshot_identifier: int

        :param error_count:
            The value to assign to the error_count property of this AwrSnapshotSummary.
        :type error_count: int

        """
        self.swagger_types = {
            'awr_source_database_id': 'str',
            'instance_number': 'int',
            'time_db_startup': 'datetime',
            'time_snapshot_begin': 'datetime',
            'time_snapshot_end': 'datetime',
            'snapshot_identifier': 'int',
            'error_count': 'int'
        }

        self.attribute_map = {
            'awr_source_database_id': 'awrSourceDatabaseId',
            'instance_number': 'instanceNumber',
            'time_db_startup': 'timeDbStartup',
            'time_snapshot_begin': 'timeSnapshotBegin',
            'time_snapshot_end': 'timeSnapshotEnd',
            'snapshot_identifier': 'snapshotIdentifier',
            'error_count': 'errorCount'
        }

        self._awr_source_database_id = None
        self._instance_number = None
        self._time_db_startup = None
        self._time_snapshot_begin = None
        self._time_snapshot_end = None
        self._snapshot_identifier = None
        self._error_count = None

    @property
    def awr_source_database_id(self):
        """
        **[Required]** Gets the awr_source_database_id of this AwrSnapshotSummary.
        DatabaseId of the Source database for which AWR Data will be uploaded to AWR Hub.


        :return: The awr_source_database_id of this AwrSnapshotSummary.
        :rtype: str
        """
        return self._awr_source_database_id

    @awr_source_database_id.setter
    def awr_source_database_id(self, awr_source_database_id):
        """
        Sets the awr_source_database_id of this AwrSnapshotSummary.
        DatabaseId of the Source database for which AWR Data will be uploaded to AWR Hub.


        :param awr_source_database_id: The awr_source_database_id of this AwrSnapshotSummary.
        :type: str
        """
        self._awr_source_database_id = awr_source_database_id

    @property
    def instance_number(self):
        """
        Gets the instance_number of this AwrSnapshotSummary.
        The database instance number.


        :return: The instance_number of this AwrSnapshotSummary.
        :rtype: int
        """
        return self._instance_number

    @instance_number.setter
    def instance_number(self, instance_number):
        """
        Sets the instance_number of this AwrSnapshotSummary.
        The database instance number.


        :param instance_number: The instance_number of this AwrSnapshotSummary.
        :type: int
        """
        self._instance_number = instance_number

    @property
    def time_db_startup(self):
        """
        Gets the time_db_startup of this AwrSnapshotSummary.
        The timestamp of the database startup.


        :return: The time_db_startup of this AwrSnapshotSummary.
        :rtype: datetime
        """
        return self._time_db_startup

    @time_db_startup.setter
    def time_db_startup(self, time_db_startup):
        """
        Sets the time_db_startup of this AwrSnapshotSummary.
        The timestamp of the database startup.


        :param time_db_startup: The time_db_startup of this AwrSnapshotSummary.
        :type: datetime
        """
        self._time_db_startup = time_db_startup

    @property
    def time_snapshot_begin(self):
        """
        Gets the time_snapshot_begin of this AwrSnapshotSummary.
        The start time of the snapshot.


        :return: The time_snapshot_begin of this AwrSnapshotSummary.
        :rtype: datetime
        """
        return self._time_snapshot_begin

    @time_snapshot_begin.setter
    def time_snapshot_begin(self, time_snapshot_begin):
        """
        Sets the time_snapshot_begin of this AwrSnapshotSummary.
        The start time of the snapshot.


        :param time_snapshot_begin: The time_snapshot_begin of this AwrSnapshotSummary.
        :type: datetime
        """
        self._time_snapshot_begin = time_snapshot_begin

    @property
    def time_snapshot_end(self):
        """
        Gets the time_snapshot_end of this AwrSnapshotSummary.
        The end time of the snapshot.


        :return: The time_snapshot_end of this AwrSnapshotSummary.
        :rtype: datetime
        """
        return self._time_snapshot_end

    @time_snapshot_end.setter
    def time_snapshot_end(self, time_snapshot_end):
        """
        Sets the time_snapshot_end of this AwrSnapshotSummary.
        The end time of the snapshot.


        :param time_snapshot_end: The time_snapshot_end of this AwrSnapshotSummary.
        :type: datetime
        """
        self._time_snapshot_end = time_snapshot_end

    @property
    def snapshot_identifier(self):
        """
        **[Required]** Gets the snapshot_identifier of this AwrSnapshotSummary.
        The identifier of the snapshot.


        :return: The snapshot_identifier of this AwrSnapshotSummary.
        :rtype: int
        """
        return self._snapshot_identifier

    @snapshot_identifier.setter
    def snapshot_identifier(self, snapshot_identifier):
        """
        Sets the snapshot_identifier of this AwrSnapshotSummary.
        The identifier of the snapshot.


        :param snapshot_identifier: The snapshot_identifier of this AwrSnapshotSummary.
        :type: int
        """
        self._snapshot_identifier = snapshot_identifier

    @property
    def error_count(self):
        """
        Gets the error_count of this AwrSnapshotSummary.
        The total number of errors.


        :return: The error_count of this AwrSnapshotSummary.
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """
        Sets the error_count of this AwrSnapshotSummary.
        The total number of errors.


        :param error_count: The error_count of this AwrSnapshotSummary.
        :type: int
        """
        self._error_count = error_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .activate_order_details import ActivateOrderDetails
from .assigned_subscription import AssignedSubscription
from .assigned_subscription_collection import AssignedSubscriptionCollection
from .assigned_subscription_summary import AssignedSubscriptionSummary
from .available_region_collection import AvailableRegionCollection
from .available_region_summary import AvailableRegionSummary
from .create_child_tenancy_details import CreateChildTenancyDetails
from .create_domain_details import CreateDomainDetails
from .create_domain_governance_details import CreateDomainGovernanceDetails
from .create_sender_invitation_details import CreateSenderInvitationDetails
from .create_subscription_mapping_details import CreateSubscriptionMappingDetails
from .domain import Domain
from .domain_collection import DomainCollection
from .domain_governance import DomainGovernance
from .domain_governance_collection import DomainGovernanceCollection
from .domain_governance_summary import DomainGovernanceSummary
from .domain_summary import DomainSummary
from .link import Link
from .link_collection import LinkCollection
from .link_summary import LinkSummary
from .order import Order
from .organization import Organization
from .organization_collection import OrganizationCollection
from .organization_summary import OrganizationSummary
from .organization_tenancy import OrganizationTenancy
from .organization_tenancy_collection import OrganizationTenancyCollection
from .organization_tenancy_summary import OrganizationTenancySummary
from .recipient_invitation import RecipientInvitation
from .recipient_invitation_collection import RecipientInvitationCollection
from .recipient_invitation_summary import RecipientInvitationSummary
from .sender_invitation import SenderInvitation
from .sender_invitation_collection import SenderInvitationCollection
from .sender_invitation_summary import SenderInvitationSummary
from .sku import Sku
from .subscription import Subscription
from .subscription_collection import SubscriptionCollection
from .subscription_info import SubscriptionInfo
from .subscription_mapping import SubscriptionMapping
from .subscription_mapping_collection import SubscriptionMappingCollection
from .subscription_mapping_summary import SubscriptionMappingSummary
from .subscription_sku import SubscriptionSku
from .subscription_summary import SubscriptionSummary
from .update_domain_details import UpdateDomainDetails
from .update_domain_governance_details import UpdateDomainGovernanceDetails
from .update_organization_details import UpdateOrganizationDetails
from .update_recipient_invitation_details import UpdateRecipientInvitationDetails
from .update_sender_invitation_details import UpdateSenderInvitationDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for tenant_manager_control_plane services.
tenant_manager_control_plane_type_mapping = {
    "ActivateOrderDetails": ActivateOrderDetails,
    "AssignedSubscription": AssignedSubscription,
    "AssignedSubscriptionCollection": AssignedSubscriptionCollection,
    "AssignedSubscriptionSummary": AssignedSubscriptionSummary,
    "AvailableRegionCollection": AvailableRegionCollection,
    "AvailableRegionSummary": AvailableRegionSummary,
    "CreateChildTenancyDetails": CreateChildTenancyDetails,
    "CreateDomainDetails": CreateDomainDetails,
    "CreateDomainGovernanceDetails": CreateDomainGovernanceDetails,
    "CreateSenderInvitationDetails": CreateSenderInvitationDetails,
    "CreateSubscriptionMappingDetails": CreateSubscriptionMappingDetails,
    "Domain": Domain,
    "DomainCollection": DomainCollection,
    "DomainGovernance": DomainGovernance,
    "DomainGovernanceCollection": DomainGovernanceCollection,
    "DomainGovernanceSummary": DomainGovernanceSummary,
    "DomainSummary": DomainSummary,
    "Link": Link,
    "LinkCollection": LinkCollection,
    "LinkSummary": LinkSummary,
    "Order": Order,
    "Organization": Organization,
    "OrganizationCollection": OrganizationCollection,
    "OrganizationSummary": OrganizationSummary,
    "OrganizationTenancy": OrganizationTenancy,
    "OrganizationTenancyCollection": OrganizationTenancyCollection,
    "OrganizationTenancySummary": OrganizationTenancySummary,
    "RecipientInvitation": RecipientInvitation,
    "RecipientInvitationCollection": RecipientInvitationCollection,
    "RecipientInvitationSummary": RecipientInvitationSummary,
    "SenderInvitation": SenderInvitation,
    "SenderInvitationCollection": SenderInvitationCollection,
    "SenderInvitationSummary": SenderInvitationSummary,
    "Sku": Sku,
    "Subscription": Subscription,
    "SubscriptionCollection": SubscriptionCollection,
    "SubscriptionInfo": SubscriptionInfo,
    "SubscriptionMapping": SubscriptionMapping,
    "SubscriptionMappingCollection": SubscriptionMappingCollection,
    "SubscriptionMappingSummary": SubscriptionMappingSummary,
    "SubscriptionSku": SubscriptionSku,
    "SubscriptionSummary": SubscriptionSummary,
    "UpdateDomainDetails": UpdateDomainDetails,
    "UpdateDomainGovernanceDetails": UpdateDomainGovernanceDetails,
    "UpdateOrganizationDetails": UpdateOrganizationDetails,
    "UpdateRecipientInvitationDetails": UpdateRecipientInvitationDetails,
    "UpdateSenderInvitationDetails": UpdateSenderInvitationDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseKeyHistoryEntry(object):
    """
    The Autonomous Database `Vault`__ service key management history entry.

    __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseKeyHistoryEntry object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AutonomousDatabaseKeyHistoryEntry.
        :type id: str

        :param kms_key_version_id:
            The value to assign to the kms_key_version_id property of this AutonomousDatabaseKeyHistoryEntry.
        :type kms_key_version_id: str

        :param vault_id:
            The value to assign to the vault_id property of this AutonomousDatabaseKeyHistoryEntry.
        :type vault_id: str

        :param time_activated:
            The value to assign to the time_activated property of this AutonomousDatabaseKeyHistoryEntry.
        :type time_activated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'kms_key_version_id': 'str',
            'vault_id': 'str',
            'time_activated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'kms_key_version_id': 'kmsKeyVersionId',
            'vault_id': 'vaultId',
            'time_activated': 'timeActivated'
        }

        self._id = None
        self._kms_key_version_id = None
        self._vault_id = None
        self._time_activated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutonomousDatabaseKeyHistoryEntry.
        The id of the Autonomous Database `Vault`__ service key management history entry.

        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The id of this AutonomousDatabaseKeyHistoryEntry.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutonomousDatabaseKeyHistoryEntry.
        The id of the Autonomous Database `Vault`__ service key management history entry.

        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param id: The id of this AutonomousDatabaseKeyHistoryEntry.
        :type: str
        """
        self._id = id

    @property
    def kms_key_version_id(self):
        """
        Gets the kms_key_version_id of this AutonomousDatabaseKeyHistoryEntry.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :return: The kms_key_version_id of this AutonomousDatabaseKeyHistoryEntry.
        :rtype: str
        """
        return self._kms_key_version_id

    @kms_key_version_id.setter
    def kms_key_version_id(self, kms_key_version_id):
        """
        Sets the kms_key_version_id of this AutonomousDatabaseKeyHistoryEntry.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :param kms_key_version_id: The kms_key_version_id of this AutonomousDatabaseKeyHistoryEntry.
        :type: str
        """
        self._kms_key_version_id = kms_key_version_id

    @property
    def vault_id(self):
        """
        Gets the vault_id of this AutonomousDatabaseKeyHistoryEntry.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :return: The vault_id of this AutonomousDatabaseKeyHistoryEntry.
        :rtype: str
        """
        return self._vault_id

    @vault_id.setter
    def vault_id(self, vault_id):
        """
        Sets the vault_id of this AutonomousDatabaseKeyHistoryEntry.
        The `OCID`__ of the Oracle Cloud Infrastructure `vault`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts


        :param vault_id: The vault_id of this AutonomousDatabaseKeyHistoryEntry.
        :type: str
        """
        self._vault_id = vault_id

    @property
    def time_activated(self):
        """
        Gets the time_activated of this AutonomousDatabaseKeyHistoryEntry.
        The date and time the kms key activated.


        :return: The time_activated of this AutonomousDatabaseKeyHistoryEntry.
        :rtype: datetime
        """
        return self._time_activated

    @time_activated.setter
    def time_activated(self, time_activated):
        """
        Sets the time_activated of this AutonomousDatabaseKeyHistoryEntry.
        The date and time the kms key activated.


        :param time_activated: The time_activated of this AutonomousDatabaseKeyHistoryEntry.
        :type: datetime
        """
        self._time_activated = time_activated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .ephemeral_resource_principals_signer import EphemeralResourcePrincipalSigner


class EphemeralResourcePrincipalsDelegationTokenSigner(EphemeralResourcePrincipalSigner):
    """
       This signer takes the following parameters:
        - session_token
        - private_key
        - private_key_passphrase

            These three parameters may be used in one of two modes. In the first mode, they contain the actual
            contents of the Resource Pricipals Session Token, private key (in PEM format) and the passphrase. This mode is only useful for
            short-lived programs.

            In the second mode, if these parameters contain absolute paths, then those paths are taken as the
            on-filesystem location of the values in question. The signer may attempt to reload these values from
            the filesystem on receiving a 401 response from an OCI service. This mode is used in cases where the
            program executes in an environment where an external provider may inject updated tokens into
            the filesystem.

        - region: the canonical region name
            This is utilised in locating the "local" endpoints of services.

        - delegation_token : The Delegation token to be used for signing the request.

    """

    def __init__(self, **kwargs):
        self.delegation_token = kwargs['delegation_token']
        generic_headers = ["date", "(request-target)", "host", "opc-obo-token"]
        super(EphemeralResourcePrincipalsDelegationTokenSigner, self).__init__(generic_headers=generic_headers, **kwargs)

    # opc-obo-token is added to the request headers
    def do_request_sign(self, request, enforce_content_headers=True):
        request.headers['opc-obo-token'] = self.delegation_token
        super(EphemeralResourcePrincipalsDelegationTokenSigner, self).do_request_sign(request, enforce_content_headers)
        return request



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TunnelRouteSummary(object):
    """
    The routes advertised to the Customer and the routes received from the Customer
    """

    #: A constant which can be used with the advertiser property of a TunnelRouteSummary.
    #: This constant has a value of "CUSTOMER"
    ADVERTISER_CUSTOMER = "CUSTOMER"

    #: A constant which can be used with the advertiser property of a TunnelRouteSummary.
    #: This constant has a value of "ORACLE"
    ADVERTISER_ORACLE = "ORACLE"

    def __init__(self, **kwargs):
        """
        Initializes a new TunnelRouteSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param prefix:
            The value to assign to the prefix property of this TunnelRouteSummary.
        :type prefix: str

        :param age:
            The value to assign to the age property of this TunnelRouteSummary.
        :type age: int

        :param is_best_path:
            The value to assign to the is_best_path property of this TunnelRouteSummary.
        :type is_best_path: bool

        :param as_path:
            The value to assign to the as_path property of this TunnelRouteSummary.
        :type as_path: list[int]

        :param advertiser:
            The value to assign to the advertiser property of this TunnelRouteSummary.
            Allowed values for this property are: "CUSTOMER", "ORACLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type advertiser: str

        """
        self.swagger_types = {
            'prefix': 'str',
            'age': 'int',
            'is_best_path': 'bool',
            'as_path': 'list[int]',
            'advertiser': 'str'
        }

        self.attribute_map = {
            'prefix': 'prefix',
            'age': 'age',
            'is_best_path': 'isBestPath',
            'as_path': 'asPath',
            'advertiser': 'advertiser'
        }

        self._prefix = None
        self._age = None
        self._is_best_path = None
        self._as_path = None
        self._advertiser = None

    @property
    def prefix(self):
        """
        Gets the prefix of this TunnelRouteSummary.
        BGP Network Layer Reachability Information


        :return: The prefix of this TunnelRouteSummary.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this TunnelRouteSummary.
        BGP Network Layer Reachability Information


        :param prefix: The prefix of this TunnelRouteSummary.
        :type: str
        """
        self._prefix = prefix

    @property
    def age(self):
        """
        Gets the age of this TunnelRouteSummary.
        The age of the route


        :return: The age of this TunnelRouteSummary.
        :rtype: int
        """
        return self._age

    @age.setter
    def age(self, age):
        """
        Sets the age of this TunnelRouteSummary.
        The age of the route


        :param age: The age of this TunnelRouteSummary.
        :type: int
        """
        self._age = age

    @property
    def is_best_path(self):
        """
        Gets the is_best_path of this TunnelRouteSummary.
        Is this the best route


        :return: The is_best_path of this TunnelRouteSummary.
        :rtype: bool
        """
        return self._is_best_path

    @is_best_path.setter
    def is_best_path(self, is_best_path):
        """
        Sets the is_best_path of this TunnelRouteSummary.
        Is this the best route


        :param is_best_path: The is_best_path of this TunnelRouteSummary.
        :type: bool
        """
        self._is_best_path = is_best_path

    @property
    def as_path(self):
        """
        Gets the as_path of this TunnelRouteSummary.
        List of ASNs in AS Path


        :return: The as_path of this TunnelRouteSummary.
        :rtype: list[int]
        """
        return self._as_path

    @as_path.setter
    def as_path(self, as_path):
        """
        Sets the as_path of this TunnelRouteSummary.
        List of ASNs in AS Path


        :param as_path: The as_path of this TunnelRouteSummary.
        :type: list[int]
        """
        self._as_path = as_path

    @property
    def advertiser(self):
        """
        Gets the advertiser of this TunnelRouteSummary.
        Route advertiser

        Allowed values for this property are: "CUSTOMER", "ORACLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The advertiser of this TunnelRouteSummary.
        :rtype: str
        """
        return self._advertiser

    @advertiser.setter
    def advertiser(self, advertiser):
        """
        Sets the advertiser of this TunnelRouteSummary.
        Route advertiser


        :param advertiser: The advertiser of this TunnelRouteSummary.
        :type: str
        """
        allowed_values = ["CUSTOMER", "ORACLE"]
        if not value_allowed_none_or_none_sentinel(advertiser, allowed_values):
            advertiser = 'UNKNOWN_ENUM_VALUE'
        self._advertiser = advertiser

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RemoveVirtualMachineFromVmClusterDetails(object):
    """
    Details of removing Virtual Machines from the VM Cluster. Applies to Exadata Cloud@Customer instances only.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RemoveVirtualMachineFromVmClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param db_servers:
            The value to assign to the db_servers property of this RemoveVirtualMachineFromVmClusterDetails.
        :type db_servers: list[oci.database.models.DbServerDetails]

        """
        self.swagger_types = {
            'db_servers': 'list[DbServerDetails]'
        }

        self.attribute_map = {
            'db_servers': 'dbServers'
        }

        self._db_servers = None

    @property
    def db_servers(self):
        """
        **[Required]** Gets the db_servers of this RemoveVirtualMachineFromVmClusterDetails.
        The list of Exacc DB servers for the cluster to be removed.


        :return: The db_servers of this RemoveVirtualMachineFromVmClusterDetails.
        :rtype: list[oci.database.models.DbServerDetails]
        """
        return self._db_servers

    @db_servers.setter
    def db_servers(self, db_servers):
        """
        Sets the db_servers of this RemoveVirtualMachineFromVmClusterDetails.
        The list of Exacc DB servers for the cluster to be removed.


        :param db_servers: The db_servers of this RemoveVirtualMachineFromVmClusterDetails.
        :type: list[oci.database.models.DbServerDetails]
        """
        self._db_servers = db_servers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TestBdsObjectStorageConnectionDetails(object):
    """
    Test access to specified Object Storage bucket using the API key.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TestBdsObjectStorageConnectionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_storage_uri:
            The value to assign to the object_storage_uri property of this TestBdsObjectStorageConnectionDetails.
        :type object_storage_uri: str

        :param passphrase:
            The value to assign to the passphrase property of this TestBdsObjectStorageConnectionDetails.
        :type passphrase: str

        :param object_storage_region:
            The value to assign to the object_storage_region property of this TestBdsObjectStorageConnectionDetails.
        :type object_storage_region: str

        """
        self.swagger_types = {
            'object_storage_uri': 'str',
            'passphrase': 'str',
            'object_storage_region': 'str'
        }

        self.attribute_map = {
            'object_storage_uri': 'objectStorageUri',
            'passphrase': 'passphrase',
            'object_storage_region': 'objectStorageRegion'
        }

        self._object_storage_uri = None
        self._passphrase = None
        self._object_storage_region = None

    @property
    def object_storage_uri(self):
        """
        **[Required]** Gets the object_storage_uri of this TestBdsObjectStorageConnectionDetails.
        An Oracle Cloud Infrastructure URI to which this connection must be attempted. See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :return: The object_storage_uri of this TestBdsObjectStorageConnectionDetails.
        :rtype: str
        """
        return self._object_storage_uri

    @object_storage_uri.setter
    def object_storage_uri(self, object_storage_uri):
        """
        Sets the object_storage_uri of this TestBdsObjectStorageConnectionDetails.
        An Oracle Cloud Infrastructure URI to which this connection must be attempted. See https://docs.cloud.oracle.com/iaas/Content/API/SDKDocs/hdfsconnector.htm#uriformat.


        :param object_storage_uri: The object_storage_uri of this TestBdsObjectStorageConnectionDetails.
        :type: str
        """
        self._object_storage_uri = object_storage_uri

    @property
    def passphrase(self):
        """
        **[Required]** Gets the passphrase of this TestBdsObjectStorageConnectionDetails.
        Base64 passphrase used to secure the private key which will be created on user behalf.


        :return: The passphrase of this TestBdsObjectStorageConnectionDetails.
        :rtype: str
        """
        return self._passphrase

    @passphrase.setter
    def passphrase(self, passphrase):
        """
        Sets the passphrase of this TestBdsObjectStorageConnectionDetails.
        Base64 passphrase used to secure the private key which will be created on user behalf.


        :param passphrase: The passphrase of this TestBdsObjectStorageConnectionDetails.
        :type: str
        """
        self._passphrase = passphrase

    @property
    def object_storage_region(self):
        """
        Gets the object_storage_region of this TestBdsObjectStorageConnectionDetails.
        The name of the region to establish the Object Storage endpoint. Example us-phoenix-1 .


        :return: The object_storage_region of this TestBdsObjectStorageConnectionDetails.
        :rtype: str
        """
        return self._object_storage_region

    @object_storage_region.setter
    def object_storage_region(self, object_storage_region):
        """
        Sets the object_storage_region of this TestBdsObjectStorageConnectionDetails.
        The name of the region to establish the Object Storage endpoint. Example us-phoenix-1 .


        :param object_storage_region: The object_storage_region of this TestBdsObjectStorageConnectionDetails.
        :type: str
        """
        self._object_storage_region = object_storage_region

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StandardTagDefinitionTemplate(object):
    """
    The template of the tag definition. This object includes necessary details to create the provided standard tag definition.
    """

    #: A constant which can be used with the type property of a StandardTagDefinitionTemplate.
    #: This constant has a value of "ENUM"
    TYPE_ENUM = "ENUM"

    #: A constant which can be used with the type property of a StandardTagDefinitionTemplate.
    #: This constant has a value of "STRING"
    TYPE_STRING = "STRING"

    #: A constant which can be used with the enum_mutability property of a StandardTagDefinitionTemplate.
    #: This constant has a value of "IMMUTABLE"
    ENUM_MUTABILITY_IMMUTABLE = "IMMUTABLE"

    #: A constant which can be used with the enum_mutability property of a StandardTagDefinitionTemplate.
    #: This constant has a value of "MUTABLE"
    ENUM_MUTABILITY_MUTABLE = "MUTABLE"

    #: A constant which can be used with the enum_mutability property of a StandardTagDefinitionTemplate.
    #: This constant has a value of "APPENDABLE"
    ENUM_MUTABILITY_APPENDABLE = "APPENDABLE"

    def __init__(self, **kwargs):
        """
        Initializes a new StandardTagDefinitionTemplate object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this StandardTagDefinitionTemplate.
        :type description: str

        :param tag_definition_name:
            The value to assign to the tag_definition_name property of this StandardTagDefinitionTemplate.
        :type tag_definition_name: str

        :param type:
            The value to assign to the type property of this StandardTagDefinitionTemplate.
            Allowed values for this property are: "ENUM", "STRING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param possible_values:
            The value to assign to the possible_values property of this StandardTagDefinitionTemplate.
        :type possible_values: list[str]

        :param is_cost_tracking:
            The value to assign to the is_cost_tracking property of this StandardTagDefinitionTemplate.
        :type is_cost_tracking: bool

        :param enum_mutability:
            The value to assign to the enum_mutability property of this StandardTagDefinitionTemplate.
            Allowed values for this property are: "IMMUTABLE", "MUTABLE", "APPENDABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type enum_mutability: str

        """
        self.swagger_types = {
            'description': 'str',
            'tag_definition_name': 'str',
            'type': 'str',
            'possible_values': 'list[str]',
            'is_cost_tracking': 'bool',
            'enum_mutability': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'tag_definition_name': 'tagDefinitionName',
            'type': 'type',
            'possible_values': 'possibleValues',
            'is_cost_tracking': 'isCostTracking',
            'enum_mutability': 'enumMutability'
        }

        self._description = None
        self._tag_definition_name = None
        self._type = None
        self._possible_values = None
        self._is_cost_tracking = None
        self._enum_mutability = None

    @property
    def description(self):
        """
        **[Required]** Gets the description of this StandardTagDefinitionTemplate.
        The default description of the tag namespace that users can use to create the tag definition


        :return: The description of this StandardTagDefinitionTemplate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this StandardTagDefinitionTemplate.
        The default description of the tag namespace that users can use to create the tag definition


        :param description: The description of this StandardTagDefinitionTemplate.
        :type: str
        """
        self._description = description

    @property
    def tag_definition_name(self):
        """
        **[Required]** Gets the tag_definition_name of this StandardTagDefinitionTemplate.
        The name of this standard tag definition


        :return: The tag_definition_name of this StandardTagDefinitionTemplate.
        :rtype: str
        """
        return self._tag_definition_name

    @tag_definition_name.setter
    def tag_definition_name(self, tag_definition_name):
        """
        Sets the tag_definition_name of this StandardTagDefinitionTemplate.
        The name of this standard tag definition


        :param tag_definition_name: The tag_definition_name of this StandardTagDefinitionTemplate.
        :type: str
        """
        self._tag_definition_name = tag_definition_name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this StandardTagDefinitionTemplate.
        The type of tag definition. Enum or string.

        Allowed values for this property are: "ENUM", "STRING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this StandardTagDefinitionTemplate.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this StandardTagDefinitionTemplate.
        The type of tag definition. Enum or string.


        :param type: The type of this StandardTagDefinitionTemplate.
        :type: str
        """
        allowed_values = ["ENUM", "STRING"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def possible_values(self):
        """
        Gets the possible_values of this StandardTagDefinitionTemplate.
        List of possible values. An optional parameter that will be present if the type of definition is enum.


        :return: The possible_values of this StandardTagDefinitionTemplate.
        :rtype: list[str]
        """
        return self._possible_values

    @possible_values.setter
    def possible_values(self, possible_values):
        """
        Sets the possible_values of this StandardTagDefinitionTemplate.
        List of possible values. An optional parameter that will be present if the type of definition is enum.


        :param possible_values: The possible_values of this StandardTagDefinitionTemplate.
        :type: list[str]
        """
        self._possible_values = possible_values

    @property
    def is_cost_tracking(self):
        """
        **[Required]** Gets the is_cost_tracking of this StandardTagDefinitionTemplate.
        Is the tag a cost tracking tag. Default will be false as cost tracking tags have been deprecated


        :return: The is_cost_tracking of this StandardTagDefinitionTemplate.
        :rtype: bool
        """
        return self._is_cost_tracking

    @is_cost_tracking.setter
    def is_cost_tracking(self, is_cost_tracking):
        """
        Sets the is_cost_tracking of this StandardTagDefinitionTemplate.
        Is the tag a cost tracking tag. Default will be false as cost tracking tags have been deprecated


        :param is_cost_tracking: The is_cost_tracking of this StandardTagDefinitionTemplate.
        :type: bool
        """
        self._is_cost_tracking = is_cost_tracking

    @property
    def enum_mutability(self):
        """
        Gets the enum_mutability of this StandardTagDefinitionTemplate.
        The mutability of the possible values list for enum tags. This will default to IMMUTABLE for string value tags

        Allowed values for this property are: "IMMUTABLE", "MUTABLE", "APPENDABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The enum_mutability of this StandardTagDefinitionTemplate.
        :rtype: str
        """
        return self._enum_mutability

    @enum_mutability.setter
    def enum_mutability(self, enum_mutability):
        """
        Sets the enum_mutability of this StandardTagDefinitionTemplate.
        The mutability of the possible values list for enum tags. This will default to IMMUTABLE for string value tags


        :param enum_mutability: The enum_mutability of this StandardTagDefinitionTemplate.
        :type: str
        """
        allowed_values = ["IMMUTABLE", "MUTABLE", "APPENDABLE"]
        if not value_allowed_none_or_none_sentinel(enum_mutability, allowed_values):
            enum_mutability = 'UNKNOWN_ENUM_VALUE'
        self._enum_mutability = enum_mutability

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateBdsMetastoreConfigurationDetails(object):
    """
    The request body when creating BDS metastore configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateBdsMetastoreConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateBdsMetastoreConfigurationDetails.
        :type display_name: str

        :param metastore_id:
            The value to assign to the metastore_id property of this CreateBdsMetastoreConfigurationDetails.
        :type metastore_id: str

        :param bds_api_key_id:
            The value to assign to the bds_api_key_id property of this CreateBdsMetastoreConfigurationDetails.
        :type bds_api_key_id: str

        :param bds_api_key_passphrase:
            The value to assign to the bds_api_key_passphrase property of this CreateBdsMetastoreConfigurationDetails.
        :type bds_api_key_passphrase: str

        :param cluster_admin_password:
            The value to assign to the cluster_admin_password property of this CreateBdsMetastoreConfigurationDetails.
        :type cluster_admin_password: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'metastore_id': 'str',
            'bds_api_key_id': 'str',
            'bds_api_key_passphrase': 'str',
            'cluster_admin_password': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'metastore_id': 'metastoreId',
            'bds_api_key_id': 'bdsApiKeyId',
            'bds_api_key_passphrase': 'bdsApiKeyPassphrase',
            'cluster_admin_password': 'clusterAdminPassword'
        }

        self._display_name = None
        self._metastore_id = None
        self._bds_api_key_id = None
        self._bds_api_key_passphrase = None
        self._cluster_admin_password = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateBdsMetastoreConfigurationDetails.
        The display name of the metastore configuration


        :return: The display_name of this CreateBdsMetastoreConfigurationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateBdsMetastoreConfigurationDetails.
        The display name of the metastore configuration


        :param display_name: The display_name of this CreateBdsMetastoreConfigurationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def metastore_id(self):
        """
        **[Required]** Gets the metastore_id of this CreateBdsMetastoreConfigurationDetails.
        The OCID of the Data Catalog metastore.


        :return: The metastore_id of this CreateBdsMetastoreConfigurationDetails.
        :rtype: str
        """
        return self._metastore_id

    @metastore_id.setter
    def metastore_id(self, metastore_id):
        """
        Sets the metastore_id of this CreateBdsMetastoreConfigurationDetails.
        The OCID of the Data Catalog metastore.


        :param metastore_id: The metastore_id of this CreateBdsMetastoreConfigurationDetails.
        :type: str
        """
        self._metastore_id = metastore_id

    @property
    def bds_api_key_id(self):
        """
        **[Required]** Gets the bds_api_key_id of this CreateBdsMetastoreConfigurationDetails.
        The ID of BDS Api Key used for Data Catalog metastore integration.


        :return: The bds_api_key_id of this CreateBdsMetastoreConfigurationDetails.
        :rtype: str
        """
        return self._bds_api_key_id

    @bds_api_key_id.setter
    def bds_api_key_id(self, bds_api_key_id):
        """
        Sets the bds_api_key_id of this CreateBdsMetastoreConfigurationDetails.
        The ID of BDS Api Key used for Data Catalog metastore integration.


        :param bds_api_key_id: The bds_api_key_id of this CreateBdsMetastoreConfigurationDetails.
        :type: str
        """
        self._bds_api_key_id = bds_api_key_id

    @property
    def bds_api_key_passphrase(self):
        """
        **[Required]** Gets the bds_api_key_passphrase of this CreateBdsMetastoreConfigurationDetails.
        Base-64 encoded passphrase of the BDS Api Key.


        :return: The bds_api_key_passphrase of this CreateBdsMetastoreConfigurationDetails.
        :rtype: str
        """
        return self._bds_api_key_passphrase

    @bds_api_key_passphrase.setter
    def bds_api_key_passphrase(self, bds_api_key_passphrase):
        """
        Sets the bds_api_key_passphrase of this CreateBdsMetastoreConfigurationDetails.
        Base-64 encoded passphrase of the BDS Api Key.


        :param bds_api_key_passphrase: The bds_api_key_passphrase of this CreateBdsMetastoreConfigurationDetails.
        :type: str
        """
        self._bds_api_key_passphrase = bds_api_key_passphrase

    @property
    def cluster_admin_password(self):
        """
        **[Required]** Gets the cluster_admin_password of this CreateBdsMetastoreConfigurationDetails.
        Base-64 encoded password for the cluster admin user.


        :return: The cluster_admin_password of this CreateBdsMetastoreConfigurationDetails.
        :rtype: str
        """
        return self._cluster_admin_password

    @cluster_admin_password.setter
    def cluster_admin_password(self, cluster_admin_password):
        """
        Sets the cluster_admin_password of this CreateBdsMetastoreConfigurationDetails.
        Base-64 encoded password for the cluster admin user.


        :param cluster_admin_password: The cluster_admin_password of this CreateBdsMetastoreConfigurationDetails.
        :type: str
        """
        self._cluster_admin_password = cluster_admin_password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .monitored_instance import MonitoredInstance
from .monitored_instance_collection import MonitoredInstanceCollection
from .monitored_instance_summary import MonitoredInstanceSummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for appmgmt_control services.
appmgmt_control_type_mapping = {
    "MonitoredInstance": MonitoredInstance,
    "MonitoredInstanceCollection": MonitoredInstanceCollection,
    "MonitoredInstanceSummary": MonitoredInstanceSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BlockchainPlatformPatchSummary(object):
    """
    Patch Details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BlockchainPlatformPatchSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BlockchainPlatformPatchSummary.
        :type id: str

        :param service_version:
            The value to assign to the service_version property of this BlockchainPlatformPatchSummary.
        :type service_version: str

        :param patch_info_url:
            The value to assign to the patch_info_url property of this BlockchainPlatformPatchSummary.
        :type patch_info_url: str

        :param time_patch_due:
            The value to assign to the time_patch_due property of this BlockchainPlatformPatchSummary.
        :type time_patch_due: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'service_version': 'str',
            'patch_info_url': 'str',
            'time_patch_due': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'service_version': 'serviceVersion',
            'patch_info_url': 'patchInfoUrl',
            'time_patch_due': 'timePatchDue'
        }

        self._id = None
        self._service_version = None
        self._patch_info_url = None
        self._time_patch_due = None

    @property
    def id(self):
        """
        Gets the id of this BlockchainPlatformPatchSummary.
        patch id


        :return: The id of this BlockchainPlatformPatchSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BlockchainPlatformPatchSummary.
        patch id


        :param id: The id of this BlockchainPlatformPatchSummary.
        :type: str
        """
        self._id = id

    @property
    def service_version(self):
        """
        Gets the service_version of this BlockchainPlatformPatchSummary.
        patch service version


        :return: The service_version of this BlockchainPlatformPatchSummary.
        :rtype: str
        """
        return self._service_version

    @service_version.setter
    def service_version(self, service_version):
        """
        Sets the service_version of this BlockchainPlatformPatchSummary.
        patch service version


        :param service_version: The service_version of this BlockchainPlatformPatchSummary.
        :type: str
        """
        self._service_version = service_version

    @property
    def patch_info_url(self):
        """
        Gets the patch_info_url of this BlockchainPlatformPatchSummary.
        A URL for the patch specific documentation


        :return: The patch_info_url of this BlockchainPlatformPatchSummary.
        :rtype: str
        """
        return self._patch_info_url

    @patch_info_url.setter
    def patch_info_url(self, patch_info_url):
        """
        Sets the patch_info_url of this BlockchainPlatformPatchSummary.
        A URL for the patch specific documentation


        :param patch_info_url: The patch_info_url of this BlockchainPlatformPatchSummary.
        :type: str
        """
        self._patch_info_url = patch_info_url

    @property
    def time_patch_due(self):
        """
        Gets the time_patch_due of this BlockchainPlatformPatchSummary.
        patch due date for customer initiated patching


        :return: The time_patch_due of this BlockchainPlatformPatchSummary.
        :rtype: datetime
        """
        return self._time_patch_due

    @time_patch_due.setter
    def time_patch_due(self, time_patch_due):
        """
        Sets the time_patch_due of this BlockchainPlatformPatchSummary.
        patch due date for customer initiated patching


        :param time_patch_due: The time_patch_due of this BlockchainPlatformPatchSummary.
        :type: datetime
        """
        self._time_patch_due = time_patch_due

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SnapshotDatasetDetails(object):
    """
    Allows outputting the latest records paired with annotations and write them to object storage.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SnapshotDatasetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param are_annotations_included:
            The value to assign to the are_annotations_included property of this SnapshotDatasetDetails.
        :type are_annotations_included: bool

        :param are_unannotated_records_included:
            The value to assign to the are_unannotated_records_included property of this SnapshotDatasetDetails.
        :type are_unannotated_records_included: bool

        :param export_details:
            The value to assign to the export_details property of this SnapshotDatasetDetails.
        :type export_details: oci.data_labeling_service.models.ObjectStorageSnapshotExportDetails

        :param export_format:
            The value to assign to the export_format property of this SnapshotDatasetDetails.
        :type export_format: oci.data_labeling_service.models.ExportFormat

        """
        self.swagger_types = {
            'are_annotations_included': 'bool',
            'are_unannotated_records_included': 'bool',
            'export_details': 'ObjectStorageSnapshotExportDetails',
            'export_format': 'ExportFormat'
        }

        self.attribute_map = {
            'are_annotations_included': 'areAnnotationsIncluded',
            'are_unannotated_records_included': 'areUnannotatedRecordsIncluded',
            'export_details': 'exportDetails',
            'export_format': 'exportFormat'
        }

        self._are_annotations_included = None
        self._are_unannotated_records_included = None
        self._export_details = None
        self._export_format = None

    @property
    def are_annotations_included(self):
        """
        **[Required]** Gets the are_annotations_included of this SnapshotDatasetDetails.
        Whether annotations are to be included in the export dataset digest.


        :return: The are_annotations_included of this SnapshotDatasetDetails.
        :rtype: bool
        """
        return self._are_annotations_included

    @are_annotations_included.setter
    def are_annotations_included(self, are_annotations_included):
        """
        Sets the are_annotations_included of this SnapshotDatasetDetails.
        Whether annotations are to be included in the export dataset digest.


        :param are_annotations_included: The are_annotations_included of this SnapshotDatasetDetails.
        :type: bool
        """
        self._are_annotations_included = are_annotations_included

    @property
    def are_unannotated_records_included(self):
        """
        **[Required]** Gets the are_unannotated_records_included of this SnapshotDatasetDetails.
        Whether to include records that have yet to be annotated in the export dataset digest.


        :return: The are_unannotated_records_included of this SnapshotDatasetDetails.
        :rtype: bool
        """
        return self._are_unannotated_records_included

    @are_unannotated_records_included.setter
    def are_unannotated_records_included(self, are_unannotated_records_included):
        """
        Sets the are_unannotated_records_included of this SnapshotDatasetDetails.
        Whether to include records that have yet to be annotated in the export dataset digest.


        :param are_unannotated_records_included: The are_unannotated_records_included of this SnapshotDatasetDetails.
        :type: bool
        """
        self._are_unannotated_records_included = are_unannotated_records_included

    @property
    def export_details(self):
        """
        **[Required]** Gets the export_details of this SnapshotDatasetDetails.

        :return: The export_details of this SnapshotDatasetDetails.
        :rtype: oci.data_labeling_service.models.ObjectStorageSnapshotExportDetails
        """
        return self._export_details

    @export_details.setter
    def export_details(self, export_details):
        """
        Sets the export_details of this SnapshotDatasetDetails.

        :param export_details: The export_details of this SnapshotDatasetDetails.
        :type: oci.data_labeling_service.models.ObjectStorageSnapshotExportDetails
        """
        self._export_details = export_details

    @property
    def export_format(self):
        """
        Gets the export_format of this SnapshotDatasetDetails.

        :return: The export_format of this SnapshotDatasetDetails.
        :rtype: oci.data_labeling_service.models.ExportFormat
        """
        return self._export_format

    @export_format.setter
    def export_format(self, export_format):
        """
        Sets the export_format of this SnapshotDatasetDetails.

        :param export_format: The export_format of this SnapshotDatasetDetails.
        :type: oci.data_labeling_service.models.ExportFormat
        """
        self._export_format = export_format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .entity import Entity
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenericEntity(Entity):
    """
    This is an extensible entity type for users, and the base entity type for some annotation formats.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenericEntity object with values from keyword arguments. The default value of the :py:attr:`~oci.data_labeling_service_dataplane.models.GenericEntity.entity_type` attribute
        of this class is ``GENERIC`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_type:
            The value to assign to the entity_type property of this GenericEntity.
            Allowed values for this property are: "GENERIC", "IMAGEOBJECTSELECTION", "TEXTSELECTION"
        :type entity_type: str

        :param labels:
            The value to assign to the labels property of this GenericEntity.
        :type labels: list[oci.data_labeling_service_dataplane.models.Label]

        :param extended_metadata:
            The value to assign to the extended_metadata property of this GenericEntity.
        :type extended_metadata: dict(str, str)

        """
        self.swagger_types = {
            'entity_type': 'str',
            'labels': 'list[Label]',
            'extended_metadata': 'dict(str, str)'
        }

        self.attribute_map = {
            'entity_type': 'entityType',
            'labels': 'labels',
            'extended_metadata': 'extendedMetadata'
        }

        self._entity_type = None
        self._labels = None
        self._extended_metadata = None
        self._entity_type = 'GENERIC'

    @property
    def labels(self):
        """
        **[Required]** Gets the labels of this GenericEntity.
        A collection of label entities.


        :return: The labels of this GenericEntity.
        :rtype: list[oci.data_labeling_service_dataplane.models.Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this GenericEntity.
        A collection of label entities.


        :param labels: The labels of this GenericEntity.
        :type: list[oci.data_labeling_service_dataplane.models.Label]
        """
        self._labels = labels

    @property
    def extended_metadata(self):
        """
        Gets the extended_metadata of this GenericEntity.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :return: The extended_metadata of this GenericEntity.
        :rtype: dict(str, str)
        """
        return self._extended_metadata

    @extended_metadata.setter
    def extended_metadata(self, extended_metadata):
        """
        Sets the extended_metadata of this GenericEntity.
        A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
        For example: `{\"bar-key\": \"value\"}`


        :param extended_metadata: The extended_metadata of this GenericEntity.
        :type: dict(str, str)
        """
        self._extended_metadata = extended_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_host_insight_details import CreateHostInsightDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateEmManagedExternalHostInsightDetails(CreateHostInsightDetails):
    """
    The information about the EM-managed external host to be analyzed.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateEmManagedExternalHostInsightDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.CreateEmManagedExternalHostInsightDetails.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_HOST`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this CreateEmManagedExternalHostInsightDetails.
            Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST", "EM_MANAGED_EXTERNAL_HOST"
        :type entity_source: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateEmManagedExternalHostInsightDetails.
        :type compartment_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateEmManagedExternalHostInsightDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateEmManagedExternalHostInsightDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this CreateEmManagedExternalHostInsightDetails.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_bridge_id:
            The value to assign to the enterprise_manager_bridge_id property of this CreateEmManagedExternalHostInsightDetails.
        :type enterprise_manager_bridge_id: str

        :param enterprise_manager_entity_identifier:
            The value to assign to the enterprise_manager_entity_identifier property of this CreateEmManagedExternalHostInsightDetails.
        :type enterprise_manager_entity_identifier: str

        :param exadata_insight_id:
            The value to assign to the exadata_insight_id property of this CreateEmManagedExternalHostInsightDetails.
        :type exadata_insight_id: str

        """
        self.swagger_types = {
            'entity_source': 'str',
            'compartment_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_bridge_id': 'str',
            'enterprise_manager_entity_identifier': 'str',
            'exadata_insight_id': 'str'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'compartment_id': 'compartmentId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_bridge_id': 'enterpriseManagerBridgeId',
            'enterprise_manager_entity_identifier': 'enterpriseManagerEntityIdentifier',
            'exadata_insight_id': 'exadataInsightId'
        }

        self._entity_source = None
        self._compartment_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._enterprise_manager_identifier = None
        self._enterprise_manager_bridge_id = None
        self._enterprise_manager_entity_identifier = None
        self._exadata_insight_id = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_HOST'

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this CreateEmManagedExternalHostInsightDetails.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this CreateEmManagedExternalHostInsightDetails.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this CreateEmManagedExternalHostInsightDetails.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this CreateEmManagedExternalHostInsightDetails.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_bridge_id(self):
        """
        **[Required]** Gets the enterprise_manager_bridge_id of this CreateEmManagedExternalHostInsightDetails.
        OPSI Enterprise Manager Bridge OCID


        :return: The enterprise_manager_bridge_id of this CreateEmManagedExternalHostInsightDetails.
        :rtype: str
        """
        return self._enterprise_manager_bridge_id

    @enterprise_manager_bridge_id.setter
    def enterprise_manager_bridge_id(self, enterprise_manager_bridge_id):
        """
        Sets the enterprise_manager_bridge_id of this CreateEmManagedExternalHostInsightDetails.
        OPSI Enterprise Manager Bridge OCID


        :param enterprise_manager_bridge_id: The enterprise_manager_bridge_id of this CreateEmManagedExternalHostInsightDetails.
        :type: str
        """
        self._enterprise_manager_bridge_id = enterprise_manager_bridge_id

    @property
    def enterprise_manager_entity_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_entity_identifier of this CreateEmManagedExternalHostInsightDetails.
        Enterprise Manager Entity Unique Identifier


        :return: The enterprise_manager_entity_identifier of this CreateEmManagedExternalHostInsightDetails.
        :rtype: str
        """
        return self._enterprise_manager_entity_identifier

    @enterprise_manager_entity_identifier.setter
    def enterprise_manager_entity_identifier(self, enterprise_manager_entity_identifier):
        """
        Sets the enterprise_manager_entity_identifier of this CreateEmManagedExternalHostInsightDetails.
        Enterprise Manager Entity Unique Identifier


        :param enterprise_manager_entity_identifier: The enterprise_manager_entity_identifier of this CreateEmManagedExternalHostInsightDetails.
        :type: str
        """
        self._enterprise_manager_entity_identifier = enterprise_manager_entity_identifier

    @property
    def exadata_insight_id(self):
        """
        Gets the exadata_insight_id of this CreateEmManagedExternalHostInsightDetails.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The exadata_insight_id of this CreateEmManagedExternalHostInsightDetails.
        :rtype: str
        """
        return self._exadata_insight_id

    @exadata_insight_id.setter
    def exadata_insight_id(self, exadata_insight_id):
        """
        Sets the exadata_insight_id of this CreateEmManagedExternalHostInsightDetails.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param exadata_insight_id: The exadata_insight_id of this CreateEmManagedExternalHostInsightDetails.
        :type: str
        """
        self._exadata_insight_id = exadata_insight_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TunnelPhaseOneDetails(object):
    """
    Tunnel detail information specific to IPSec phase 1.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TunnelPhaseOneDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_custom_phase_one_config:
            The value to assign to the is_custom_phase_one_config property of this TunnelPhaseOneDetails.
        :type is_custom_phase_one_config: bool

        :param lifetime:
            The value to assign to the lifetime property of this TunnelPhaseOneDetails.
        :type lifetime: int

        :param remaining_lifetime:
            The value to assign to the remaining_lifetime property of this TunnelPhaseOneDetails.
        :type remaining_lifetime: int

        :param custom_authentication_algorithm:
            The value to assign to the custom_authentication_algorithm property of this TunnelPhaseOneDetails.
        :type custom_authentication_algorithm: str

        :param negotiated_authentication_algorithm:
            The value to assign to the negotiated_authentication_algorithm property of this TunnelPhaseOneDetails.
        :type negotiated_authentication_algorithm: str

        :param custom_encryption_algorithm:
            The value to assign to the custom_encryption_algorithm property of this TunnelPhaseOneDetails.
        :type custom_encryption_algorithm: str

        :param negotiated_encryption_algorithm:
            The value to assign to the negotiated_encryption_algorithm property of this TunnelPhaseOneDetails.
        :type negotiated_encryption_algorithm: str

        :param custom_dh_group:
            The value to assign to the custom_dh_group property of this TunnelPhaseOneDetails.
        :type custom_dh_group: str

        :param negotiated_dh_group:
            The value to assign to the negotiated_dh_group property of this TunnelPhaseOneDetails.
        :type negotiated_dh_group: str

        :param is_ike_established:
            The value to assign to the is_ike_established property of this TunnelPhaseOneDetails.
        :type is_ike_established: bool

        :param remaining_lifetime_last_retrieved:
            The value to assign to the remaining_lifetime_last_retrieved property of this TunnelPhaseOneDetails.
        :type remaining_lifetime_last_retrieved: datetime

        """
        self.swagger_types = {
            'is_custom_phase_one_config': 'bool',
            'lifetime': 'int',
            'remaining_lifetime': 'int',
            'custom_authentication_algorithm': 'str',
            'negotiated_authentication_algorithm': 'str',
            'custom_encryption_algorithm': 'str',
            'negotiated_encryption_algorithm': 'str',
            'custom_dh_group': 'str',
            'negotiated_dh_group': 'str',
            'is_ike_established': 'bool',
            'remaining_lifetime_last_retrieved': 'datetime'
        }

        self.attribute_map = {
            'is_custom_phase_one_config': 'isCustomPhaseOneConfig',
            'lifetime': 'lifetime',
            'remaining_lifetime': 'remainingLifetime',
            'custom_authentication_algorithm': 'customAuthenticationAlgorithm',
            'negotiated_authentication_algorithm': 'negotiatedAuthenticationAlgorithm',
            'custom_encryption_algorithm': 'customEncryptionAlgorithm',
            'negotiated_encryption_algorithm': 'negotiatedEncryptionAlgorithm',
            'custom_dh_group': 'customDhGroup',
            'negotiated_dh_group': 'negotiatedDhGroup',
            'is_ike_established': 'isIkeEstablished',
            'remaining_lifetime_last_retrieved': 'remainingLifetimeLastRetrieved'
        }

        self._is_custom_phase_one_config = None
        self._lifetime = None
        self._remaining_lifetime = None
        self._custom_authentication_algorithm = None
        self._negotiated_authentication_algorithm = None
        self._custom_encryption_algorithm = None
        self._negotiated_encryption_algorithm = None
        self._custom_dh_group = None
        self._negotiated_dh_group = None
        self._is_ike_established = None
        self._remaining_lifetime_last_retrieved = None

    @property
    def is_custom_phase_one_config(self):
        """
        Gets the is_custom_phase_one_config of this TunnelPhaseOneDetails.
        Indicates whether custom phase one configuration is enabled.


        :return: The is_custom_phase_one_config of this TunnelPhaseOneDetails.
        :rtype: bool
        """
        return self._is_custom_phase_one_config

    @is_custom_phase_one_config.setter
    def is_custom_phase_one_config(self, is_custom_phase_one_config):
        """
        Sets the is_custom_phase_one_config of this TunnelPhaseOneDetails.
        Indicates whether custom phase one configuration is enabled.


        :param is_custom_phase_one_config: The is_custom_phase_one_config of this TunnelPhaseOneDetails.
        :type: bool
        """
        self._is_custom_phase_one_config = is_custom_phase_one_config

    @property
    def lifetime(self):
        """
        Gets the lifetime of this TunnelPhaseOneDetails.
        The total configured lifetime of an IKE security association.


        :return: The lifetime of this TunnelPhaseOneDetails.
        :rtype: int
        """
        return self._lifetime

    @lifetime.setter
    def lifetime(self, lifetime):
        """
        Sets the lifetime of this TunnelPhaseOneDetails.
        The total configured lifetime of an IKE security association.


        :param lifetime: The lifetime of this TunnelPhaseOneDetails.
        :type: int
        """
        self._lifetime = lifetime

    @property
    def remaining_lifetime(self):
        """
        Gets the remaining_lifetime of this TunnelPhaseOneDetails.
        The lifetime remaining before the key is refreshed.


        :return: The remaining_lifetime of this TunnelPhaseOneDetails.
        :rtype: int
        """
        return self._remaining_lifetime

    @remaining_lifetime.setter
    def remaining_lifetime(self, remaining_lifetime):
        """
        Sets the remaining_lifetime of this TunnelPhaseOneDetails.
        The lifetime remaining before the key is refreshed.


        :param remaining_lifetime: The remaining_lifetime of this TunnelPhaseOneDetails.
        :type: int
        """
        self._remaining_lifetime = remaining_lifetime

    @property
    def custom_authentication_algorithm(self):
        """
        Gets the custom_authentication_algorithm of this TunnelPhaseOneDetails.
        Custom authentication algorithm


        :return: The custom_authentication_algorithm of this TunnelPhaseOneDetails.
        :rtype: str
        """
        return self._custom_authentication_algorithm

    @custom_authentication_algorithm.setter
    def custom_authentication_algorithm(self, custom_authentication_algorithm):
        """
        Sets the custom_authentication_algorithm of this TunnelPhaseOneDetails.
        Custom authentication algorithm


        :param custom_authentication_algorithm: The custom_authentication_algorithm of this TunnelPhaseOneDetails.
        :type: str
        """
        self._custom_authentication_algorithm = custom_authentication_algorithm

    @property
    def negotiated_authentication_algorithm(self):
        """
        Gets the negotiated_authentication_algorithm of this TunnelPhaseOneDetails.
        The negotiated authentication algorithm.


        :return: The negotiated_authentication_algorithm of this TunnelPhaseOneDetails.
        :rtype: str
        """
        return self._negotiated_authentication_algorithm

    @negotiated_authentication_algorithm.setter
    def negotiated_authentication_algorithm(self, negotiated_authentication_algorithm):
        """
        Sets the negotiated_authentication_algorithm of this TunnelPhaseOneDetails.
        The negotiated authentication algorithm.


        :param negotiated_authentication_algorithm: The negotiated_authentication_algorithm of this TunnelPhaseOneDetails.
        :type: str
        """
        self._negotiated_authentication_algorithm = negotiated_authentication_algorithm

    @property
    def custom_encryption_algorithm(self):
        """
        Gets the custom_encryption_algorithm of this TunnelPhaseOneDetails.
        Custom encryption algorithm.


        :return: The custom_encryption_algorithm of this TunnelPhaseOneDetails.
        :rtype: str
        """
        return self._custom_encryption_algorithm

    @custom_encryption_algorithm.setter
    def custom_encryption_algorithm(self, custom_encryption_algorithm):
        """
        Sets the custom_encryption_algorithm of this TunnelPhaseOneDetails.
        Custom encryption algorithm.


        :param custom_encryption_algorithm: The custom_encryption_algorithm of this TunnelPhaseOneDetails.
        :type: str
        """
        self._custom_encryption_algorithm = custom_encryption_algorithm

    @property
    def negotiated_encryption_algorithm(self):
        """
        Gets the negotiated_encryption_algorithm of this TunnelPhaseOneDetails.
        The negotiated encryption algorithm.


        :return: The negotiated_encryption_algorithm of this TunnelPhaseOneDetails.
        :rtype: str
        """
        return self._negotiated_encryption_algorithm

    @negotiated_encryption_algorithm.setter
    def negotiated_encryption_algorithm(self, negotiated_encryption_algorithm):
        """
        Sets the negotiated_encryption_algorithm of this TunnelPhaseOneDetails.
        The negotiated encryption algorithm.


        :param negotiated_encryption_algorithm: The negotiated_encryption_algorithm of this TunnelPhaseOneDetails.
        :type: str
        """
        self._negotiated_encryption_algorithm = negotiated_encryption_algorithm

    @property
    def custom_dh_group(self):
        """
        Gets the custom_dh_group of this TunnelPhaseOneDetails.
        Custom Diffie-Hellman group.


        :return: The custom_dh_group of this TunnelPhaseOneDetails.
        :rtype: str
        """
        return self._custom_dh_group

    @custom_dh_group.setter
    def custom_dh_group(self, custom_dh_group):
        """
        Sets the custom_dh_group of this TunnelPhaseOneDetails.
        Custom Diffie-Hellman group.


        :param custom_dh_group: The custom_dh_group of this TunnelPhaseOneDetails.
        :type: str
        """
        self._custom_dh_group = custom_dh_group

    @property
    def negotiated_dh_group(self):
        """
        Gets the negotiated_dh_group of this TunnelPhaseOneDetails.
        The negotiated Diffie-Hellman group.


        :return: The negotiated_dh_group of this TunnelPhaseOneDetails.
        :rtype: str
        """
        return self._negotiated_dh_group

    @negotiated_dh_group.setter
    def negotiated_dh_group(self, negotiated_dh_group):
        """
        Sets the negotiated_dh_group of this TunnelPhaseOneDetails.
        The negotiated Diffie-Hellman group.


        :param negotiated_dh_group: The negotiated_dh_group of this TunnelPhaseOneDetails.
        :type: str
        """
        self._negotiated_dh_group = negotiated_dh_group

    @property
    def is_ike_established(self):
        """
        Gets the is_ike_established of this TunnelPhaseOneDetails.
        Indicates whether IKE Phase 1 is established.


        :return: The is_ike_established of this TunnelPhaseOneDetails.
        :rtype: bool
        """
        return self._is_ike_established

    @is_ike_established.setter
    def is_ike_established(self, is_ike_established):
        """
        Sets the is_ike_established of this TunnelPhaseOneDetails.
        Indicates whether IKE Phase 1 is established.


        :param is_ike_established: The is_ike_established of this TunnelPhaseOneDetails.
        :type: bool
        """
        self._is_ike_established = is_ike_established

    @property
    def remaining_lifetime_last_retrieved(self):
        """
        Gets the remaining_lifetime_last_retrieved of this TunnelPhaseOneDetails.
        The date and time we retrieved the remaining lifetime, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The remaining_lifetime_last_retrieved of this TunnelPhaseOneDetails.
        :rtype: datetime
        """
        return self._remaining_lifetime_last_retrieved

    @remaining_lifetime_last_retrieved.setter
    def remaining_lifetime_last_retrieved(self, remaining_lifetime_last_retrieved):
        """
        Sets the remaining_lifetime_last_retrieved of this TunnelPhaseOneDetails.
        The date and time we retrieved the remaining lifetime, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param remaining_lifetime_last_retrieved: The remaining_lifetime_last_retrieved of this TunnelPhaseOneDetails.
        :type: datetime
        """
        self._remaining_lifetime_last_retrieved = remaining_lifetime_last_retrieved

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApplicationSummary(object):
    """
    Summary of the Vb Instance's applications.
    """

    #: A constant which can be used with the state property of a ApplicationSummary.
    #: This constant has a value of "STAGE"
    STATE_STAGE = "STAGE"

    #: A constant which can be used with the state property of a ApplicationSummary.
    #: This constant has a value of "LIVE"
    STATE_LIVE = "LIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new ApplicationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ApplicationSummary.
        :type id: str

        :param project_id:
            The value to assign to the project_id property of this ApplicationSummary.
        :type project_id: str

        :param version:
            The value to assign to the version property of this ApplicationSummary.
        :type version: str

        :param state:
            The value to assign to the state property of this ApplicationSummary.
            Allowed values for this property are: "STAGE", "LIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type state: str

        """
        self.swagger_types = {
            'id': 'str',
            'project_id': 'str',
            'version': 'str',
            'state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'project_id': 'projectId',
            'version': 'version',
            'state': 'state'
        }

        self._id = None
        self._project_id = None
        self._version = None
        self._state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ApplicationSummary.
        Unique identifier of the application.


        :return: The id of this ApplicationSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ApplicationSummary.
        Unique identifier of the application.


        :param id: The id of this ApplicationSummary.
        :type: str
        """
        self._id = id

    @property
    def project_id(self):
        """
        **[Required]** Gets the project_id of this ApplicationSummary.
        Project identifier.


        :return: The project_id of this ApplicationSummary.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """
        Sets the project_id of this ApplicationSummary.
        Project identifier.


        :param project_id: The project_id of this ApplicationSummary.
        :type: str
        """
        self._project_id = project_id

    @property
    def version(self):
        """
        **[Required]** Gets the version of this ApplicationSummary.
        Version of deployed application.


        :return: The version of this ApplicationSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ApplicationSummary.
        Version of deployed application.


        :param version: The version of this ApplicationSummary.
        :type: str
        """
        self._version = version

    @property
    def state(self):
        """
        **[Required]** Gets the state of this ApplicationSummary.
        Represents the deployment state of the application.

        Allowed values for this property are: "STAGE", "LIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The state of this ApplicationSummary.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ApplicationSummary.
        Represents the deployment state of the application.


        :param state: The state of this ApplicationSummary.
        :type: str
        """
        allowed_values = ["STAGE", "LIVE"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            state = 'UNKNOWN_ENUM_VALUE'
        self._state = state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
